Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(190)

Unified Diff: webrtc/modules/congestion_controller/congestion_controller_unittest.cc

Issue 2415543002: Set min BWE bitrate form 10kbps to 5kbps and centralize minimum bitrate. (Closed)
Patch Set: Fixed unittest Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/modules/congestion_controller/congestion_controller_unittest.cc
diff --git a/webrtc/modules/congestion_controller/congestion_controller_unittest.cc b/webrtc/modules/congestion_controller/congestion_controller_unittest.cc
index e840294d9f09a96da12b5631606ab717c2227e16..5fd3b52aa38701a759a2d26b7741ace3dbfa44bd 100644
--- a/webrtc/modules/congestion_controller/congestion_controller_unittest.cc
+++ b/webrtc/modules/congestion_controller/congestion_controller_unittest.cc
@@ -135,10 +135,12 @@ TEST_F(CongestionControllerTest, ResetBweAndBitrates) {
controller_->ResetBweAndBitrates(new_bitrate, -1, -1);
// If the bitrate is reset to -1, the new starting bitrate will be
- // the minimum default bitrate 10000bps.
- int min_default_bitrate = 10000;
- EXPECT_CALL(observer_, OnNetworkChanged(min_default_bitrate, _, _));
- EXPECT_CALL(*pacer_, SetEstimatedBitrate(min_default_bitrate));
+ // the minimum default bitrate kMinBitrateBps.
minyue-webrtc 2016/10/13 08:12:31 does the test depend on the actual value?
michaelt 2016/10/13 09:38:41 Yes the test insert ileal values and expect then t
+ EXPECT_CALL(
the sun 2016/10/12 15:29:36 strange formatting - did git cl format do this?
michaelt 2016/10/13 06:34:49 Yes, this is done by "cl format"
+ observer_,
+ OnNetworkChanged(remote_bitrate_estimator_defines::kMinBitrateBps, _, _));
+ EXPECT_CALL(*pacer_, SetEstimatedBitrate(
+ remote_bitrate_estimator_defines::kMinBitrateBps));
controller_->ResetBweAndBitrates(-1, -1, -1);
}

Powered by Google App Engine
This is Rietveld 408576698